# jupyter-vibecheck

A Jupyter Widget to get atomic feedback as a student progresses through a didactic jupyter notebook.

<img width="1164" alt="image" src="https://user-images.githubusercontent.com/693511/215613608-4746b8ed-77ff-4696-9f92-3ba720448a8f.png">
